@@ -2,7 +2,7 @@
 #ifndef _GLIBMM_EXCEPTIONHANDLER_H
 #define _GLIBMM_EXCEPTIONHANDLER_H
 
-/* $Id: exceptionhandler.h,v 1.2 2004/02/10 14:26:04 murrayc Exp $ */
+/* $Id: exceptionhandler.h,v 1.2.8.1 2006/05/10 08:05:02 murrayc Exp $ */
 
 /* exceptionhandler.h
  *
@@ -24,7 +24,9 @@
  */
 
 #include <sigc++/sigc++.h>
+#include <glibmmconfig.h>
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 
 namespace Glib
 {
@@ -40,6 +42,7 @@ void exception_handlers_invoke() throw();
 
 } // namespace Glib
 
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 #endif /* _GLIBMM_EXCEPTIONHANDLER_H */
 
